// NOTICE.H : copyright notices...

// Copyright (C) 2000 Tommi Hassinen.

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#include "config.h"	// this is target-dependent...

#ifndef NOTICE_H
#define NOTICE_H

/* added by Robert Williams for Compaq cxx, alpha 11/28/01 */
#define __USE_STD_IOSTREAM

#include <iostream>
using namespace std;

/*################################################################################################*/

#define COPYRIGHT_NOTICE_LINES	25

const char * get_copyright_notice_line(int);
void print_full_copyright_notice(ostream &);

/*################################################################################################*/

#endif	// NOTICE_H

// eof
